@@ -1,5 +1,5 @@
 # misc. file io concerned subroutines
-# $Id: fio.pl,v 1.1.1.1 2000/03/18 06:54:10 odakker Exp $
+# $Id: fio.pl,v 1.2 2000/10/13 21:19:59 okuyama Exp $
 # Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
 # see COPYING.TXT for terms of license.
 
@@ -32,3 +32,18 @@ sub mkdir {
 	mkdir($dnam, 0777) || &die("mkdir $dnam");
 }
 
+#sub syslog {
+#	local($message) = @_;
+#	system "/usr/bin/logger -t $0 '$message'"
+#		|| die "logger $!";
+#}
+
+sub Syslog {
+    use Sys::Syslog qw(:DEFAULT setlogsock);
+    local($message) = @_;
+
+    setlogsock unix;
+    openlog($0,'cons,pid','user');
+    syslog('info',"$message");
+    closelog();
+}
